
/* Petit programme simple pour tester le clavier du SHIELD LCD.
   La boucle de base inverse la sortie LED 2 à chaque rotation.
   la fréquence mesuréest de 90 Hz soit une période de 11241µS.
   En réalité, le temps de la boucle fait la moitié soit 5620µS.
   Chaque touche génère un BIP au relacher du B.P. */

#include <LiquidCrystal.h>

//--------------------- Définition des broches d'E/S ------------------------
#define Pilotage_RETRO 13 // Pilotage du rétroéclairage.
#define BUZZER 2 // Pilotage du bruiteur.
#define LED_Verte 3 // Pilotage de la sortie synchronisation.

LiquidCrystal MonEcran(8, 9, 4, 5, 6, 7);

//------------------------ Constantes du programme --------------- ----------
#define Version_PGM "Version 09-08-17"
#define NB_tests_antirebonds 50 // Nombre de tests de stabilisation B.P. >>> MAXI 60.

//------------------------- variables du programme --------------------------
boolean Retro_ECL_actif;
byte Ordre_du_BP;

void setup(){
  pinMode(Pilotage_RETRO, OUTPUT); digitalWrite(Pilotage_RETRO, HIGH);
  pinMode(BUZZER, OUTPUT); digitalWrite(BUZZER, LOW);
  pinMode(LED_Verte, OUTPUT);
  MonEcran.begin(16,2); pinMode(Pilotage_RETRO, OUTPUT);
  MonEcran.setCursor(0,0); MonEcran.print(">>> Bonjour. <<<");
  digitalWrite(Pilotage_RETRO, HIGH); Retro_ECL_actif = true;} // Allume le rétroéclairage.

void loop() {
  Tester_le_BP_A0();
  if (Ordre_du_BP > 0) {
      Efface_ligne(1); MonEcran.setCursor(0,1);
      switch (Ordre_du_BP) {
              case 1 : {MonEcran.print("RIGHT"); break;}
              case 2 : {MonEcran.print("UP"); break;}
              case 3 : {MonEcran.print("DOWN"); break;}     
              case 4 : {MonEcran.print("LEFT"); break;}        
              case 5 : MonEcran.print("SELECT");} }
  digitalWrite(LED_Verte, !digitalRead(LED_Verte)); // Inverse l'état de la LED à chaque boucle.
  }
  
void BIP() {
  tone(BUZZER,3000); delay(100); noTone(BUZZER); digitalWrite(BUZZER, LOW);}

void Efface_ligne(byte Ligne) {// Zéro : Haut, 1 : Bas.
  if (Ligne ==0) MonEcran.setCursor(0,0); else MonEcran.setCursor(0,1);
  MonEcran.print("                ");}

void Tester_le_BP_A0() { // La lecture sur A0 donne 0 ou 1023 maximum.
  // >>>>>>>>>>>>> Le B.P. est câblé en "Analogique" <<<<<<<<<<<<<<<<<<
  // Aucun B.P : Temps dans la procédure court et retour = 0,
  // RIGHT = 1, UP = 2, DOWN = 3, LEFT = 4 SELECT = 5.
  Ordre_du_BP = 0; // Aucun BP appuyé.
  unsigned int Moyenne; // Valeur moyenne obtenue par la CAN de A0.
  Moyenne = 1023;
  for (byte I = 0; I < NB_tests_antirebonds; I++)
      {if (analogRead(0) < 830) Moyenne = analogRead(0);}
  //-------- Si appui détecté procéder à la mesure. --------
  if (Moyenne < 830)
     {Moyenne = 0;
      for (byte I = 0; I < NB_tests_antirebonds; I++) Moyenne = Moyenne + analogRead(0);
      //------------- Attendre le relacher du B.P. -------------
      for (byte I = 0; I < NB_tests_antirebonds; I++) {if (analogRead(0) < 830) I = 0;}
      //---------------- traite l'ordre du B.P. ----------------  
      Moyenne = int(Moyenne / NB_tests_antirebonds);
      if (Moyenne < 50) Ordre_du_BP = 1;
      if ((Moyenne > 49) && (Moyenne < 175)) Ordre_du_BP = 2;
      if ((Moyenne > 174) && (Moyenne < 330)) Ordre_du_BP = 3;
      if ((Moyenne > 329) && (Moyenne < 522)) Ordre_du_BP = 4;
      if ((Moyenne > 521) && (Moyenne < 830)) Ordre_du_BP = 5; BIP();} }
  
  
