
/* Petit programme pour montrer le problème d'exploitation des caractères spéciaux disponibles
   sur l'afficheur LCD. L'initialisation des matrices est mémorisée dans l'afficheur avec un
   maximum de huit emplacements de n°1 à n°8. Les "empreintes" des caractères spéciaux doivent
   être présentées avant Void SETUP(). On peut en écrire autant que l'on veut.
   LIMITE : À tout moment dans le programme on peut changer les matrices, mais les deux lignes
            de l'afficheur ne visualisent qu'une combinaison. Par exemple dans ce projet il ne
            sera pas possible d'utiliser les accentués et les empreintes du ruban simultanément
            en haut pour le texte, et en bas pour le sablier.  
   SOLUTION : Comme le sablier n'exige que 5 caractères spéciaux, on peut en "récupérer" trois
            en les plaçant à la fin. Dans ce démonstrateur on place les cinq empreintes géométriques
            en premier, ce qui obligera à réordonner tous les caractères spéciaux du programme complet
            "actuel", c'est à dire P09. ce choix résulte d'une simplification qui en résulte pour
            gérer le tracé du ruban analogique.  */

#include <LiquidCrystal.h>

//--------------------- Définition des broches d'E/S ------------------------
#define Pilotage_RETRO 13 // Pilotage du rétroéclairage.
#define LED_Verte 3 // Pilotage de la sortie synchronisation.
#define BUZZER 2 // Pilotage du bruiteur.

LiquidCrystal MonEcran(8, 9, 4, 5, 6, 7);
// Définition des matrices de représentation avant Void SETUP().
// On peut en écrire autant que l'on veut.
byte Eegu[8] = {2,4,14,17,31,16,14,0}; // Caractère spécial "é".
byte degre[8] = {4,10,4,0,0,0,0,0}; // Caractère spécial "°".
byte Fleche_Haut[8] = {4,14,21,4,4,4,4,0}; // Flèche vers le haut.
byte Fleche_Bas[8] = {4,4,4,4,21,14,4,0}; // Flèche vers le bas.
byte Gminuscule[8] = {0,0,15,17,17,15,1,14};
byte Pminuscule[8] = {0,0,30,17,17,30,16,16};
byte Jminuscule[8] = {4,0,15,2,2,2,18,12};
byte Damier[8] = {21,10,21,10,21,10,21,0}; // Simple grille pour démonstration.
// Matrices pour tracer le ruban linéaire.
byte I[8] = {16,16,16,16,16,16,16,16};
byte II[8] = {24,24,24,24,24,24,24,24};
byte III[8] = {28,28,28,28,28,28,28,28};
byte IIII[8] = {30,30,30,30,30,30,30,30};
byte IIIII[8] = {31,31,31,31,31,31,31,31};

//------------------------- variables du programme --------------------------
boolean Affiche_C_et_Nb;
byte Ordre_du_BP, Mode_affichage_ecran, NB_echantillons, Compteur;
byte Heures = 0, Minutes = 0, Secondes = 0;
int Mesure_NUM_CTN, CAN_U_Batterie, INDEX_MAX;
int INDEX; // Pointeur des octets situés en EEPROM.
double Temperature;
float U_Batterie; // Tension U aux bornes pour calcul de I en fonction de R.
float U_sur_Fusible; // Tension U aux bornes du fusible.
float Courant_de_decharge; // Est calculé par le programme.
float Capacite = 0;

unsigned long Ancienne_valeur_Temps_Ecoule_depuis_RESET;

void Creer_les_caracteres_textuels() {
  MonEcran.createChar(1,degre);       // Caractère spécial "°".
  MonEcran.createChar(2,Damier);      //  Position intrinsèquement disponible.
  MonEcran.createChar(3,Jminuscule); // "j" minuscule.
  MonEcran.createChar(4,Gminuscule);  // "g" minuscule.
  MonEcran.createChar(5,Pminuscule);  // "p" minuscule.
  MonEcran.createChar(6,Eegu);        // Caractère spécial "é".
  MonEcran.createChar(7,Fleche_Haut); // Flèche vers le haut.
  MonEcran.createChar(8,Fleche_Bas);}  // Flèche vers le bas.
  
void Creer_les_rubans_du_sablier() {  
  MonEcran.createChar(1,I); MonEcran.createChar(2,II); MonEcran.createChar(3,III);
  MonEcran.createChar(4,IIII); MonEcran.createChar(5,IIIII);}

void setup(){
  pinMode(Pilotage_RETRO, OUTPUT); digitalWrite(Pilotage_RETRO, HIGH);
  pinMode(BUZZER, OUTPUT); digitalWrite(BUZZER, LOW); pinMode(LED_Verte, OUTPUT);
  MonEcran.begin(16,2); }

void loop() {
 Creer_les_caracteres_textuels();
 Ecrire_ligne_du_haut(); MonEcran.print("Matrices TEXTE.");
 Ecrire_ligne_du_bas(); MonEcran.write(1); MonEcran.write(2); MonEcran.write(3);
 MonEcran.write(4); MonEcran.write(5); MonEcran.write(6); MonEcran.write(7); MonEcran.write(8);
 delay(3000);
 Creer_les_rubans_du_sablier();
 Ecrire_ligne_du_haut(); MonEcran.print("Matrices Ruban.");
 Ecrire_ligne_du_bas(); MonEcran.write(1); MonEcran.write(2); MonEcran.write(3);
 MonEcran.write(4); MonEcran.write(5);
 delay(3000);
 //==================== Les pavés sont simultanés et la ligne du haut est "brouillée" ==================== 
 Creer_les_caracteres_textuels();
 Ecrire_ligne_du_haut(); MonEcran.write(1); MonEcran.write(2); MonEcran.write(3);
 MonEcran.write(4); MonEcran.write(5); MonEcran.write(6); MonEcran.write(7); MonEcran.write(8);
 Creer_les_rubans_du_sablier();
 Ecrire_ligne_du_bas(); MonEcran.write(1); MonEcran.write(2); MonEcran.write(3);
 MonEcran.write(4); MonEcran.write(5);
 delay(3000);
 //===================== On peut toutefois avoir trois caractères textuels inchangés ===================== 
 Creer_les_caracteres_textuels();
 Ecrire_ligne_du_haut(); MonEcran.print("Capacit"); MonEcran.write(6); MonEcran.print(" / C Max"); 
 Creer_les_rubans_du_sablier();
 Ecrire_ligne_du_bas(); MonEcran.write(1); MonEcran.write(2); MonEcran.write(3);
 MonEcran.write(4); MonEcran.write(5); delay(5000); }

void Ecrire_ligne_du_haut() {
  Efface_ligne(0); MonEcran.setCursor(0,0);}
  
void Ecrire_ligne_du_bas() {
  Efface_ligne(1); MonEcran.setCursor(0,1);} 

void Efface_ligne(byte Ligne) {// Zéro : Haut, 1 : Bas.
  if (Ligne ==0) MonEcran.setCursor(0,0); else MonEcran.setCursor(0,1);
  MonEcran.print("                ");}
