
/* Petit programme pour mesurer la capacité d'une BATTERIE au PLOMB 12v.
   On suppose que le test dure moins de 10 heures. (Capacité < 50 Ah)
          Par Michel DROUI. (Pseudo Internet : Nulentout.)
          
>>>>> Penser à passer en remarque le branchement goto à Sauter_test_fusible: dans la version 
>>>>> opérationnelle du programme. (Ligne avec @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
          
DIFFERENTS BRANCHEMENTS :
 D0  : Libre pour F.E.                         A0 : Lecture du clavier à cinq boutons du SHIELD.
 D1  : Libre pour F.E.                         A1 : Mesure de la tension sur la batterie.
 D2  : Pilotage du BUZZER.                     A2 : Mesure de la présence du fusible. (Et son "delta" U.)
 D3  : LED verte inversée à chaque cycle.      A3 : Mesure de la température du bloc thermique.    
 D4  : DB4 du SHIELD LCD.                      A4 : Libre pour F.E.
 D5  : DB5 du SHIELD LCD.                      A5 : Libre pour F.E.
 D6  : DB6 du SHIELD LCD. 
 D7  : DB7 du SHIELD LCD. 
 D8  : DB7 du SHIELD LCD.
 D9  : E   du SHIELD LCD.
 D10 : Non utilisable                        
 D11 : Libre pour F.E.                      
 D12 : Libre pour F.E.
 D13 : SHIELD modifié pour que D13 pilote le rétro-éclairage sans risque pour le transistor de commutation.
 
                                                         PGM               RAM dynamique
 Avant séquences pour la mémorisation en EEPROM.   8862 Octets (27%)      414 Octets (20%)
 Mais ci-dessus le test de fin de décharge n'était pas mis en place.
 Après exploitation de l'EEPROM.                  10424 Octets (32%)      528 Octets (25%)
 
*/

#include <avr/eeprom.h> // Bibliothèque intégrée à l'IDE qui gère les entiers ,les réels ...
#include <LiquidCrystal.h>

//--------------------- Définition des broches d'E/S ------------------------
#define Pilotage_RETRO 13 // Pilotage du rétroéclairage.
#define BUZZER 2 // Pilotage du bruiteur.
#define LED_Verte 3 // Pilotage de la sortie synchronisation.
#define Capteur_KY_013 3 // A3 affectée à la mesure de température.
#define Entree_TENSION 1  // Entrée analogique A1 pour mesurer la tension Batterie.
#define Entree_Fusible 2  // Entrée analogique A2 pour mesurer la DDP au fusible.

LiquidCrystal MonEcran(8, 9, 4, 5, 6, 7);
byte Eegu[8] = {2,4,14,17,31,16,14,0}; // Caractère spécial "é".
byte degre[8] = {4,10,4,0,0,0,0,0}; // Caractère spécial "°".
byte Fleche_Haut[8] = {4,14,21,4,4,4,4,0}; // Flèche vers le haut.
byte Fleche_Bas[8] = {4,4,4,4,21,14,4,0}; // Flèche vers le bas.
byte Gminuscule[8] = {0,0,15,17,17,15,1,14};
byte Pminuscule[8] = {0,0,30,17,17,30,16,16};
byte Jminuscule[8] = {4,0,15,2,2,2,18,12};

//------------------------ Constantes du programme --------------------------
#define Version_PGM "Version 22-08-17"
#define Correction_U_Batterie 1.015 // Corrige la valeur du pont diviseur pour U batterie.
#define Correction_U_Fusible 1.018 // Corrige la valeur mesurée pour U Fusible.
#define R_Bloc_thermique 2.7  // Valeur résultante des trois résistances mises en parallèle.
#define Ucritique 11.0 // Tension en dessous de laquelle le processus de décharge sera terminé.
#define T_base_millisecondes 996  // Durée globale entre deux mesures exprimée en mS.
                                  // Valeur affinée en fonction de la QRG du quartz.
#define Seuil_pour_alerte 45 // Température qui déclenchera l'alerte thermique.
#define NB_tests_antirebonds 60 // Nombre de tests de stabilisation B.P. >>> MAXI 60.
//------------------------- variables du programme --------------------------
boolean Affiche_C_et_Nb;
byte Ordre_du_BP, Mode_affichage_ecran, NB_echantillons, Compteur;
byte Heures = 0, Minutes = 0, Secondes = 0;
int Mesure_NUM_CTN, CAN_U_Batterie, INDEX_MAX;
int INDEX; // Pointeur des octets situés en EEPROM. (Pointe le premier emplacement libre en mémorisation échantillons.)
double Temperature;
float U_Batterie; // Tension U aux bornes pour calcul de I en fonction de R.
float U_sur_Fusible; // Tension U aux bornes du fusible.
float Courant_de_decharge; // Est calculé par le programme.
float Capacite;

unsigned long Ancienne_valeur_Temps_Ecoule_depuis_RESET;

void setup(){
  pinMode(Pilotage_RETRO, OUTPUT); digitalWrite(Pilotage_RETRO,HIGH); // Allume le rétroéclairage.
  pinMode(BUZZER, OUTPUT); digitalWrite(BUZZER, LOW); pinMode(LED_Verte, OUTPUT);
  MonEcran.begin(16,2);
  MonEcran.createChar(1,degre); // Caractère spécial "°".
  MonEcran.createChar(2,Eegu);  // Caractère spécial "é".
  MonEcran.createChar(3,Fleche_Haut); // Flèche vers le haut.
  MonEcran.createChar(4,Fleche_Bas); // Flèche vers le bas.
  MonEcran.createChar(5,Gminuscule); // "g" minuscule.
  MonEcran.createChar(6,Pminuscule); // "p" minuscule.
  MonEcran.createChar(7,Jminuscule); // "j" minuscule.
  Ecrire_ligne_du_haut(); MonEcran.print(">>> Bon"); MonEcran.write(7); MonEcran.print("our. <<<");
  Ecrire_ligne_du_bas(); MonEcran.print(Version_PGM);
  Mode_affichage_ecran = 1; Attendre_un_BP(); 
  Ecrire_ligne_du_haut(); MonEcran.print("Ex"); MonEcran.write(6); MonEcran.print("lorer EPROM ?");
  Affiche_OUI_NON(); Attendre_un_BP(); if (Ordre_du_BP == 2) Exploite_Enregistrements();  
  Ecrire_ligne_du_haut(); MonEcran.print("Re"); MonEcran.write(6); MonEcran.print("rise Mesure ?");
  Affiche_OUI_NON(); Attendre_un_BP();
  if (Ordre_du_BP == 2) Restitue_le_contexte(); else Efface_le_contexte(); 
  Ecrire_ligne_du_haut(); MonEcran.print("Brancher la BAT.");
  Ecrire_ligne_du_bas();  MonEcran.print("et ra"); MonEcran.write(6); MonEcran.print("idmt un BP");
  Attendre_un_BP();  
  Ancienne_valeur_Temps_Ecoule_depuis_RESET = millis() + T_base_millisecondes;} // Initialise pour une première seconde.

void loop() {
  /* L'intégralité du traitement se fait durant l'interruption pour que les variations de durée en fonction
     des actions effectuées n'interfèrent pas sur la durée totale de la boucle de base. La précision de cette
     boucle affinée à exactement une seconde influence directement la valeur calculée de la capacité. */
     
  // >>>>>>>>>>>>>>>>>>>>>>>>>>>>> Traiter le clavier. <<<<<<<<<<<<<<<<<<<<<<<<<<<<
  Tester_le_BP_A0();
  if (Ordre_du_BP > 0) { // Sortie immédiate si pas de B.P. activé, donc T boucle = constante.
    if (Ordre_du_BP != 5) digitalWrite(Pilotage_RETRO,HIGH); // Allume le rétroéclairage.
    switch (Ordre_du_BP) { 
        case 1 : {Suspendre_le_mesurage(); break;}
        case 2 : {Mode_affichage_ecran = 1; break;} // Affiche les valeurs de U,I et C.
        case 3 : {Mode_affichage_ecran = 2; break;} // Température et Delta U sur fusible.
        case 4 : {Mode_affichage_ecran = 3; break;} // Indique le nombre d'échantillons.
        case 5 : {digitalWrite(Pilotage_RETRO,!digitalRead(Pilotage_RETRO)); }}} // Mode veille > Écran noir.
  // ++++++++++++++++++++++++ Réalisé une fois par seconde. +++++++++++++++++++++++
  if (millis() > Ancienne_valeur_Temps_Ecoule_depuis_RESET)  {
      Ancienne_valeur_Temps_Ecoule_depuis_RESET = millis() + T_base_millisecondes; // Réarme le processus.
      digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
      Secondes ++; if (Secondes > 59) {Minutes ++; Secondes = 0;}; if (Minutes > 59) {Heures ++; Minutes = 0;};
      Mesurer_le_debit_batterie(); Calcule_le_courant_fourni_par_la_batterie();
      Capacite = Capacite + (Courant_de_decharge / 3600); // Augmente la capacité cumulée au cours du temps.
      // >>>>>>>>>>>>>>>>>>>>>>>>>> Mesure de la température. <<<<<<<<<<<<<<<<<<<<<<<<<
      Mesure_NUM_CTN = analogRead(Capteur_KY_013);
      Temperature = Conversion_en_degres(Mesure_NUM_CTN);
      if (Temperature > Seuil_pour_alerte) ALERTE_FUSIBLE(); // Se termine sur une boucle infinie.
      // >>>>>>>>>>>>>>>>>>>>>>>>> Gérer l'absence du fusible <<<<<<<<<<<<<<<<<<<<<<<<<
 //     goto Sauter_test_fusible; // Permet durant la mise au point de pouvoir enlever le fusible si validé. @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
      if (U_sur_Fusible > 1.5) ALERTE_FUSIBLE(); // Déclenche l'alerte si dU sur fusible dépasse 1,5V.
      Sauter_test_fusible:
      // >>>>>>>>>>>>>>>>>>>>> Traite l'échantillonage en EEPROM. <<<<<<<<<<<<<<<<<<<<<
      Compteur++;  // Ci-dessous : Valeur 180 secondes pour sauver un échantillon toutes les 3 minutes.
      if (Compteur == 180) {Sauvegarde_un_Echantillon(); Compteur = 0;} // Réarme le compteur pour 3 minutes.
      // >>>>>>>>>>>>>>>>>>>>>>>>>>>> Rafraichir l'écran LCD. <<<<<<<<<<<<<<<<<<<<<<<<<
      switch (Mode_affichage_ecran) {
        case 1 : {Affiche_ecran_mesures(); break;} // Affiche les valeurs de U,I et C.
        case 2 : {Affiche_TMP_et_U_Fusible(); break;}
        case 3 : Affiche_Nombre_Echantillons();}
      // >>>>>>>>>>>>>>>>>>>>>>>> Teste pour la fin du processus. <<<<<<<<<<<<<<<<<<<<<
      if (U_Batterie < Ucritique) {
         Sauvegarde_le_contexte(); Mode_affichage_ecran = 1; Affiche_ecran_mesures(); Ordre_du_BP = 0; 
         while (Ordre_du_BP == 0) {
         BIP(450); digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
         BIP(300); digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
         Tester_le_BP_A0();} Fin_du_processus(); } }
  // +++++++++++++++++++++ Fin de traiter une fois par seconde. +++++++++++++++++++++++  
  } //======================================= Fin de la boucle de base =====================================
   
void Sauvegarde_le_contexte() {
  INDEX = 1023; Ecrire_un_OCTET_en_EEPROM(INDEX, NB_echantillons); // Sauvegarde le nombre d'échantillons effectués.
  INDEX = 1019; Ecrire_un_Float_en_EEPROM(INDEX, Capacite);} // Sauvegarde la valeur actuelle de la capacité.

void Restitue_le_contexte() {
  INDEX = 1023; NB_echantillons = Lire_un_OCTET_en_EEPROM(INDEX); // Restitue le nombre d'échantillons effectués.
  INDEX = 1019; Capacite = Lire_un_Float_en_EEPROM(INDEX); // Restitue la valeur actuelle de la capacité.
  // >>>>>>>>>>>>>>>> Restitue l'heure du dernier échantillon mémorisé <<<<<<<<<<<<
  INDEX = (4 * NB_echantillons) - 4; // Pointe le début du dernier échantillon.
  Heures = Lire_un_OCTET_en_EEPROM(INDEX); Minutes = Lire_un_OCTET_en_EEPROM(INDEX + 1); Secondes = 0;
  INDEX = 4 * NB_echantillons;} // Pointe le premier emplacement libre en EEPROM.

void Efface_le_contexte() {
  INDEX = 1023; Ecrire_un_OCTET_en_EEPROM(INDEX, 0); // "Vide" la mémoire d'échantillons.
  Capacite = 0; NB_echantillons = 0; Compteur = 0; INDEX = 0;} // Replace l'INDEX en début d'EEPROM.

void Sauvegarde_un_Echantillon() { // Laisse INDEX sur le premier octer libre en EEPROM.
  if (NB_echantillons < 251) {
  Ecrire_un_OCTET_en_EEPROM(INDEX, Heures); Ecrire_un_OCTET_en_EEPROM(INDEX, Minutes);
  Ecrire_un_Entier_en_EEPROM(INDEX, CAN_U_Batterie); NB_echantillons++;} }
  
void Exploite_Enregistrements() {
  INDEX = 1023; NB_echantillons = Lire_un_OCTET_en_EEPROM(INDEX); // Restitue le nombre d'échantillons effectués.
  INDEX = 1019; Capacite = Lire_un_Float_en_EEPROM(INDEX); // Restitue la valeur mémorisée de la capacité. 
  INDEX_MAX = (NB_echantillons - 1) * 4;
  if (NB_echantillons == 0) {
     Ecrire_ligne_du_haut(); MonEcran.print("> M"); MonEcran.write(2); MonEcran.print("moire vide <");
     Ecrire_ligne_du_bas(); MonEcran.print(".Faire un RESET.");
     Boucle_infinie: goto Boucle_infinie;} 
  INDEX = 0; // Pointe le premier échantillon.
  Affiche_NB_Echantillons(); Ecrire_ligne_du_bas(); MonEcran.print("Sortie "); MonEcran.write(6);
  MonEcran.print("ar RESET"); Affiche_C_et_Nb = true;
  // >>>>>>>>>>>>>>>>>>>>>>>> Gère le clavier du Shield LCD  <<<<<<<<<<<<<<<<<<<<<<
  Recommence: Affiche_ecran_Memoire(); Attendre_un_BP(); Traite_BP_Exploitation_Memoire(); goto Recommence; }
  
void Affiche_un_espace() { MonEcran.print(" "); }
  
void Affiche_ecran_Memoire() { // INDEX pointe le début d'un échantillon valide en entrée de procédure.
  if (Affiche_C_et_Nb) {
      Affiche_NB_Echantillons(); Ecrire_ligne_du_bas(); MonEcran.print("Ca"); MonEcran.write(6);
      MonEcran.print("acit"); MonEcran.write(2); Affiche_un_espace(); MonEcran.print(Capacite,2);}
  else {// Lire des octets en EEPROM ne décale pas le pointeur INDEX.
      Ecrire_ligne_du_haut(); MonEcran.print("  Valeur n"); MonEcran.write(1); Affiche_un_espace();
      MonEcran.print((INDEX / 4) + 1); // Calcule le n° échantillon en fonction de la valeur de INDEX.
      Heures = Lire_un_OCTET_en_EEPROM(INDEX); Minutes = Lire_un_OCTET_en_EEPROM(INDEX + 1);
      CAN_U_Batterie = Lire_un_Entier_en_EEPROM(INDEX + 2); Translate_U_Batterie();
      AFF_H_et_U(); } }
  
void Traite_BP_Exploitation_Memoire() {
  if (Ordre_du_BP == 5) Affiche_C_et_Nb = true; else Affiche_C_et_Nb = false;
  switch (Ordre_du_BP) {// Pointer en avant ou en arrière de 1 ou 10 emplacements. 
      case 1 : {if (INDEX < INDEX_MAX) INDEX = INDEX + 4; else BIP(3000); break;}
      case 2 : {if (INDEX <= (INDEX_MAX - 40)) INDEX = INDEX + 40; else BIP(3000); break;}
      case 3 : {if (INDEX > 39) INDEX = INDEX - 40; else BIP(3000); break;}
      case 4 : if (INDEX > 3) INDEX = INDEX - 4; else BIP(3000); } }

//======================================= Routines pour gérer l'EEPROM ======================================

byte Lire_un_OCTET_en_EEPROM(int ADRESSE) {
  return eeprom_read_byte((unsigned char *) ADRESSE);}

void Ecrire_un_OCTET_en_EEPROM(int ADRESSE, byte OCTET) { // Pointe l'octet libre suivant.
   eeprom_write_byte((unsigned char *) ADRESSE, OCTET); INDEX++;}
   
int Lire_un_Entier_en_EEPROM(int ADRESSE) {
  return eeprom_read_word((unsigned int *) ADRESSE);}
  
void Ecrire_un_Entier_en_EEPROM(int ADRESSE, int MOT16Bits) { // Pointe l'octet libre suivant.
   eeprom_write_word((unsigned int *) ADRESSE, MOT16Bits); INDEX++; INDEX++;}
   
float Lire_un_Float_en_EEPROM(int ADRESSE) {
  return eeprom_read_float((float *) ADRESSE);}
  
void Ecrire_un_Float_en_EEPROM(int ADRESSE, float MOT32Bits) { // Pointe l'octet libre suivant.
   eeprom_write_float((float *) ADRESSE, MOT32Bits); INDEX = INDEX + 4;}

//===========================================================================================================

void Calcule_le_courant_fourni_par_la_batterie() {// de 8610 octets passe à 8678 soit + 68 octets !
  Courant_de_decharge = (0.0071428 * U_Batterie) - 0.0071424; // calcul du courant dans le ventilateur.
  Courant_de_decharge = Courant_de_decharge +((U_Batterie - U_sur_Fusible) / R_Bloc_thermique) ; }
  //  Courant_traversant_R = ((U_Batterie - U_sur_Fusible) / R_Bloc_thermique) + 0.078; }
  
void Translate_U_Batterie() {
  U_Batterie = CAN_U_Batterie; // L'entier de numérisation passe dans le réel U_Batterie.
  U_Batterie = (U_Batterie * 20 / 1023) * Correction_U_Batterie;}
  // Pour 5 Vcc sur l'entrée le CNA retourne 1023.
  // Comme U = 4 * E on multiplie par 4 d'où le facteur 20.
      
void Mesurer_le_debit_batterie() {
  CAN_U_Batterie = analogRead(Entree_TENSION); // Uréel = quatre fois la DDP mesurée.
  // Intermédiaire de type int pour sauvegarde sur deux octets en EEPROM.
  Translate_U_Batterie(); // l'entier CAN_U_Batterie transformé en volts dans le réel U_Batterie.
  U_sur_Fusible = analogRead(Entree_Fusible); // Mesuré directement.
  U_sur_Fusible = (U_sur_Fusible * 5 / 1023) * Correction_U_Fusible;}

void Suspendre_le_mesurage() {
  digitalWrite(Pilotage_RETRO,HIGH); // Si mode veille allume le rétroéclairage.
  Ecrire_ligne_du_haut(); MonEcran.print("Fi"); MonEcran.write(5); MonEcran.print("er mesura");
  MonEcran.write(5); MonEcran.print("e ?"); Affiche_OUI_NON(); Attendre_un_BP();
  if (Ordre_du_BP == 2) {Sauvegarde_le_contexte(); Fin_du_processus();} } 

void Affiche_TMP_et_U_Fusible() { Affiche_U_sur_fusible(); Affiche_valeur_temperature();}

void Affiche_ecran_mesures() {
  Ecrire_ligne_du_haut(); MonEcran.print("C=");
  if (Capacite < 10) Affiche_un_zero();
  MonEcran.print(Capacite,2); MonEcran.print("Ah I="); MonEcran.print(Courant_de_decharge,1);
  MonEcran.print("A"); AFF_H_et_U(); } 
  
void AFF_H_et_U() {  
  Ecrire_ligne_du_bas(); if (Heures < 10) Affiche_un_zero();
  if (Heures < 1) Affiche_un_zero(); else MonEcran.print(Heures); MonEcran.print(":");
  if (Minutes < 10) Affiche_un_zero(); if (Minutes < 1) Affiche_un_zero(); else MonEcran.print(Minutes);
  MonEcran.print(":"); if (Secondes < 10) Affiche_un_zero(); if (Secondes < 1) Affiche_un_zero();
  else MonEcran.print(Secondes); MonEcran.print(" U="); MonEcran.print(U_Batterie,1); MonEcran.print("v");}
  
void Affiche_un_zero() {MonEcran.print("0");}
  
void ALERTE_TEMPERATURE() {
  Ecrire_ligne_du_haut(); MonEcran.print("ALERTE THERMIQUE"); Affiche_valeur_temperature(); ALERTE();}
  
void ALERTE_FUSIBLE() {
  Affiche_U_sur_fusible(); Ecrire_ligne_du_bas(); MonEcran.print("Pas de FUSIBLE !"); ALERTE();}
  
void ALERTE() {
  Sauvegarde_le_contexte(); digitalWrite(Pilotage_RETRO,HIGH); // Si mode veille allume le rétroéclairage.  
  Ordre_du_BP = 0; while (Ordre_du_BP == 0) {BIP(4000); BIP(3000); Tester_le_BP_A0();} Fin_du_processus();}
  
void  Fin_du_processus() {
  Ecrire_ligne_du_haut(); MonEcran.print("Mesures sauv"); MonEcran.write(2); MonEcran.print("es.");
  Ecrire_ligne_du_bas();  MonEcran.print("COUPER BATTERIE.");
  Infini: goto Infini;} // Boucle infinie pour figer l'affichage.
  
void Affiche_U_sur_fusible() {
  Ecrire_ligne_du_haut(); MonEcran.print("Fusible U="); MonEcran.print(U_sur_Fusible,2); MonEcran.print("v");}

void Affiche_valeur_temperature() {
  Ecrire_ligne_du_bas(); MonEcran.print("Temp = ");
  MonEcran.print(Temperature,1); MonEcran.write(1); MonEcran.print("C  ");}

void Affiche_NB_Echantillons() {
  Ecrire_ligne_du_haut(); MonEcran.print("Nb "); MonEcran.write(2); MonEcran.print("chant. = ");
  MonEcran.print(NB_echantillons);}
 
void Affiche_Nombre_Echantillons() {
  Affiche_NB_Echantillons(); Ecrire_ligne_du_bas(); MonEcran.print(" (Maximum 250.)");} 
 
void Affiche_OUI_NON() {
  Ecrire_ligne_du_bas(); MonEcran.print("( ");MonEcran.write(3); MonEcran.print(":OUI  "); MonEcran.write(4);
  MonEcran.print(":NON )");}  

double Conversion_en_degres(int Mesure_CTN) {
  double Tmp_Kelvin;
  Tmp_Kelvin = log(10000.0 * ((1023.0 / Mesure_CTN - 1))); 
  Tmp_Kelvin = 1 / (0.001129148 + (0.000234125 + (0.0000000876741 * Tmp_Kelvin * Tmp_Kelvin ))* Tmp_Kelvin );
  Tmp_Kelvin = Tmp_Kelvin - 273.15; // Conversion des degrés Kelvin en degrés Celcius.
  return Tmp_Kelvin; }

void Attendre_un_BP() { // Attend un clic sur l'un des cinq B.P.
  Ordre_du_BP = 0;
  while (Ordre_du_BP == 0) {Tester_le_BP_A0(); delay(30);
         digitalWrite(LED_Verte,!digitalRead(LED_Verte));} } // Inverser l'état de la LED verte.

void Efface_ligne(byte Ligne) {// Zéro : Haut, 1 : Bas.
  if (Ligne ==0) MonEcran.setCursor(0,0); else MonEcran.setCursor(0,1);
  MonEcran.print("                ");}
  
void Ecrire_ligne_du_haut() {
  Efface_ligne(0); MonEcran.setCursor(0,0);}
  
void Ecrire_ligne_du_bas() {
  Efface_ligne(1); MonEcran.setCursor(0,1);}
  
void BIP(int Frequence) {// 4000 très aigü, 3000 très fort et 500 : Mode clavier.
  tone(BUZZER,Frequence); delay(100); noTone(BUZZER); digitalWrite(BUZZER, LOW);}

void Tester_le_BP_A0() { // La lecture sur A0 donne 0 ou 1023 maximum.
  // >>>>>>>>>>>>> Le B.P. est câblé en "Analogique" <<<<<<<<<<<<<<<<<<
  // Aucun B.P : Temps dans la procédure court et retour = 0,
  // RIGHT = 1, UP = 2, DOWN = 3, LEFT = 4 SELECT = 5.
  Ordre_du_BP = 0; // Aucun BP appuyé.
  unsigned int Moyenne; // Valeur moyenne obtenue par la CAN de A0.
  Moyenne = 1023;
  for (byte I = 0; I < NB_tests_antirebonds; I++)
      {if (analogRead(0) < 830) Moyenne = analogRead(0);}
  //-------- Si appui détecté procéder à la mesure. --------
  if (Moyenne < 830)
     {Moyenne = 0;
      for (byte I = 0; I < NB_tests_antirebonds; I++) Moyenne = Moyenne + analogRead(0);
      //------------- Attendre le relacher du B.P. -------------
      for (byte I = 0; I < NB_tests_antirebonds; I++) {if (analogRead(0) < 830) I = 0;}
      //---------------- traite l'ordre du B.P. ----------------  
      Moyenne = int(Moyenne / NB_tests_antirebonds);
      if (Moyenne < 50) Ordre_du_BP = 1;
      if ((Moyenne > 49) && (Moyenne < 175)) Ordre_du_BP = 2;
      if ((Moyenne > 174) && (Moyenne < 330)) Ordre_du_BP = 3;
      if ((Moyenne > 329) && (Moyenne < 522)) Ordre_du_BP = 4;
      if ((Moyenne > 521) && (Moyenne < 830)) Ordre_du_BP = 5; BIP(500);} }
      
