
/* Petit programme pour mesurer la capacité d'une BATTERIE au PLOMB 12v.
   On suppose que le test dure moins de 10 heures. (Capacité < 50 Ah)
          Par Michel DROUI. (Pseudo Internet : Nulentout.)
          
>>>>>> Si vous rencontrez un problème : michel.droui@laposte.net
          
Directement dérivé de P09 ce logiciel inclus la représentation en "sablier" du rapport entre la Capacité
mesurée en temps réel par rapport à la capacité théorique de la batterie quand elle est neuve.

MODIFICATIONS EFFECTUÉES :
* Ordre de génération des matrices de caractères textuels modifié pour optimisation.
* Initialisation des matrices de caractères textuels effectuée dans une procédure.
* La touche SELECT alterne entre le mode écran "Nb échant" et le ruban analogique.
* Ecriture de la procédure de visualisation analogique.
* Sauvegarde de la caractéristique batterie en EEPROM pour reprise d'un mesurage.
* Corrigé certaines petites vermines :
  - Ne restituer le contexte que si EEPROM non vide.
  - Allume le rétroéclairage si fin de processus ...
* Routine de saisie de la capacité théorique de la batterie mesurée.
* Affichage de la mémoire EEPROM sur la ligne série USB.

>>>>> Penser à passer en remarque le branchement goto à Sauter_test_fusible: dans la version 
>>>>> opérationnelle du programme : Ligne avec @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
          
DIFFERENTS BRANCHEMENTS :
 D0  : Libre pour F.E.                         A0 : Lecture du clavier à cinq boutons du SHIELD.
 D1  : Libre pour F.E.                         A1 : Mesure de la tension sur la batterie.
 D2  : Pilotage du BUZZER.                     A2 : Mesure de la présence du fusible. (Et son "delta" U.)
 D3  : LED verte inversée à chaque cycle.      A3 : Mesure de la température du bloc thermique.    
 D4  : DB4 du SHIELD LCD.                      A4 : Libre pour F.E.
 D5  : DB5 du SHIELD LCD.                      A5 : Libre pour F.E.
 D6  : DB6 du SHIELD LCD. 
 D7  : DB7 du SHIELD LCD. 
 D8  : DB7 du SHIELD LCD.
 D9  : E   du SHIELD LCD.
 D10 : Non utilisable                        
 D11 : Libre pour F.E.                      
 D12 : Libre pour F.E.
 D13 : SHIELD modifié pour que D13 pilote le rétro-éclairage sans risque pour le transistor de commutation.
 
                                                                PGM               RAM dynamique
 PGM avec exploitation de l'EEPROM sans le sablier.       10424 Octets (32%)      528 Octets (25%)
 PGM avec gestion complète du ruban analogique.           11458 Octets (35%)      619 Octets (30%)
 PGM avec affichage de l'EEPROM sur la ligne série USB.   13158 Octets (40%)      874 Octets (42%)   */

#include <avr/eeprom.h> // Bibliothèque intégrée à l'IDE qui gère les entiers ,les réels ...
#include <LiquidCrystal.h>

//--------------------- Définition des broches d'E/S ------------------------
#define Pilotage_RETRO 13 // Pilotage du rétroéclairage.
#define BUZZER 2 // Pilotage du bruiteur.
#define LED_Verte 3 // Pilotage de la sortie synchronisation.
#define Capteur_KY_013 3 // A3 affectée à la mesure de température.
#define Entree_TENSION 1  // Entrée analogique A1 pour mesurer la tension Batterie.
#define Entree_Fusible 2  // Entrée analogique A2 pour mesurer la DDP au fusible.

LiquidCrystal MonEcran(8, 9, 4, 5, 6, 7);
// Définition des matrices de représentation avant Void SETUP().
// On peut en écrire autant que l'on veut.
byte Eegu[8] = {2,4,14,17,31,16,14,0}; // Caractère spécial "é".
byte degre[8] = {4,10,4,0,0,0,0,0}; // Caractère spécial "°".
byte Fleche_Haut[8] = {4,14,21,4,4,4,4,0}; // Flèche vers le haut.
byte Fleche_Bas[8] = {4,4,4,4,21,14,4,0}; // Flèche vers le bas.
byte Gminuscule[8] = {0,0,15,17,17,15,1,14};
byte Pminuscule[8] = {0,0,30,17,17,30,16,16};
byte Jminuscule[8] = {4,0,15,2,2,2,18,12};
byte Agrave[8] = {8,4,14,1,15,17,15,0};
// Matrices pour tracer le ruban linéaire.
byte I[8] = {16,16,16,16,16,16,16,16};
byte II[8] = {24,24,24,24,24,24,24,24};
byte III[8] = {28,28,28,28,28,28,28,28};
byte IIII[8] = {30,30,30,30,30,30,30,30};
byte IIIII[8] = {31,31,31,31,31,31,31,31};

//------------------------ Constantes du programme --------------------------
#define Version_PGM "Version 28-08-17" //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#define Correction_U_Batterie 1.015 // Corrige la valeur du pont diviseur pour U batterie.
#define Correction_U_Fusible 1.018 // Corrige la valeur mesurée pour U Fusible.
#define R_Bloc_thermique 2.7  // Valeur résultante des trois résistances mises en parallèle.
#define Ucritique 10.8 // Tension en dessous de laquelle le processus de décharge sera terminé.
#define T_base_millisecondes 996  // Durée globale entre deux mesures exprimée en mS.
                                  // Valeur affinée en fonction de la QRG du quartz.
#define Seuil_pour_alerte 45 // Température qui déclenchera l'alerte thermique.
#define Capacite_indiquee_sur_la_batterie 22 // Caractéristique par défaut de la batterie.

#define NB_tests_antirebonds 60 // Nombre de tests de stabilisation B.P. >>> MAXI 60.

//------------------------- Variables du programme --------------------------
boolean Affiche_C_et_Nb;
byte Ordre_du_BP, Mode_affichage_ecran, NB_echantillons, Compteur;
byte Heures = 0, Minutes = 0, Secondes = 0;
byte Capacite_theorique; // Capacité supposée pour la batterie en cours de test.
byte Num_Ech_USB; // Numéro de l'échantillon actuellement affiché sur la ligne série USB.
byte Compteur_de_ligne; // Compte le nombre de lignes affichées sur la ligne série USB.
int Mesure_NUM_CTN, CAN_U_Batterie, INDEX_MAX;
int INDEX; // Pointeur des octets situés en EEPROM. (Pointe le premier emplacement libre en mémorisation échantillons.)
double Temperature;
float U_Batterie; // Tension U aux bornes pour calcul de I en fonction de R.
float U_sur_Fusible; // Tension U aux bornes du fusible.
float Courant_de_decharge; // Est calculé par le programme.
float Capacite;
float VALEUR; // Devra être comprise entre 0 et 96.

unsigned long Ancienne_valeur_Temps_Ecoule_depuis_RESET;

void setup(){
  Serial.begin(115200);
  pinMode(Pilotage_RETRO, OUTPUT); digitalWrite(Pilotage_RETRO,HIGH); // Allume le rétroéclairage.
  pinMode(BUZZER, OUTPUT); digitalWrite(BUZZER, LOW); pinMode(LED_Verte, OUTPUT);
  MonEcran.begin(16,2);
  Creer_les_caracteres_textuels(); // Initialisation des matrices de caractères spéciaux.
  Ecrire_ligne_du_haut(); MonEcran.print(">>> Bon"); MonEcran.write(3); MonEcran.print("our. <<<");
  Ecrire_ligne_du_bas(); MonEcran.print(Version_PGM);
  Mode_affichage_ecran = 1; Attendre_un_BP(); 
  Ecrire_ligne_du_haut(); MonEcran.print("Ex"); MonEcran.write(8); MonEcran.print("lorer EPROM ?");
  Affiche_OUI_NON(); Attendre_un_BP(); if (Ordre_du_BP == 2) Exploite_Enregistrements();  
  Ecrire_ligne_du_haut(); MonEcran.print("Re"); MonEcran.write(8); MonEcran.print("rise Mesure ?");
  Affiche_OUI_NON(); Attendre_un_BP(); Capacite_theorique = Capacite_indiquee_sur_la_batterie;
  if (Ordre_du_BP == 2) Teste_EEPROM_et_Restitue_le_contexte(); else Efface_le_contexte_et_INIT_BAT(); 
  Ecrire_ligne_du_haut(); MonEcran.print("Brancher la BAT."); Ecrire_ligne_du_bas(); MonEcran.print("et ra");
  MonEcran.write(8); MonEcran.print("idmt un BP"); Attendre_un_BP(); 
  Ancienne_valeur_Temps_Ecoule_depuis_RESET = millis() + T_base_millisecondes;} // Initialise pour une première seconde.

void loop() {
  /* L'intégralité du traitement se fait durant l'interruption pour que les variations de durée en fonction
     des actions effectuées n'interfèrent pas sur la durée totale de la boucle de base. La précision de cette
     boucle affinée à exactement une seconde influence directement la valeur calculée de la capacité. */
     
  // >>>>>>>>>>>>>>>>>>>>>>>>>>>>> Traiter le clavier. <<<<<<<<<<<<<<<<<<<<<<<<<<<<
  Tester_le_BP_A0();
  if (Ordre_du_BP > 0) { // Sortie immédiate si pas de B.P. activé, donc T boucle = constante.
    if (Ordre_du_BP != 5) digitalWrite(Pilotage_RETRO,HIGH); // Allume le rétroéclairage.
    switch (Ordre_du_BP) { 
        case 1 : {Creer_les_caracteres_textuels(); Suspendre_le_mesurage(); break;}
        case 2 : {Mode_affichage_ecran = 1; break;} // Affiche les valeurs de U,I et C.
        case 3 : {Mode_affichage_ecran = 2; break;} // Température et Delta U sur fusible.
        case 4 : {if (Mode_affichage_ecran == 3) Mode_affichage_ecran = 4; // Ruban analogique.
                  else  Mode_affichage_ecran = 3; break;} // Indique le nombre d'échantillons.
        case 5 : {digitalWrite(Pilotage_RETRO,!digitalRead(Pilotage_RETRO)); }}} // Mode veille > Écran noir.
  // ++++++++++++++++++++++++ Réalisé une fois par seconde. +++++++++++++++++++++++
  if (millis() > Ancienne_valeur_Temps_Ecoule_depuis_RESET)  {
      Ancienne_valeur_Temps_Ecoule_depuis_RESET = millis() + T_base_millisecondes; // Réarme le processus.
      digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
      Secondes ++; if (Secondes > 59) {Minutes ++; Secondes = 0;}; if (Minutes > 59) {Heures ++; Minutes = 0;};
      Mesurer_le_debit_batterie(); Calcule_le_courant_fourni_par_la_batterie();
      Capacite = Capacite + (Courant_de_decharge / 3600); // Augmente la capacité cumulée au cours du temps.
      // >>>>>>>>>>>>>>>>>>>>>>>>>> Mesure de la température. <<<<<<<<<<<<<<<<<<<<<<<<<
      Mesure_NUM_CTN = analogRead(Capteur_KY_013);
      Temperature = Conversion_en_degres(Mesure_NUM_CTN);
      if (Temperature > Seuil_pour_alerte) ALERTE_TEMPERATURE(); // Se termine sur une boucle infinie.
      // >>>>>>>>>>>>>>>>>>>>>>>>> Gérer l'absence du fusible <<<<<<<<<<<<<<<<<<<<<<<<<
//      goto Sauter_test_fusible; // Permet durant la mise au point de pouvoir enlever le fusible si validé. @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
      if (U_sur_Fusible > 1.5) ALERTE_FUSIBLE(); // Déclenche l'alerte si dU sur fusible dépasse 1,5V.
      Sauter_test_fusible:
      // >>>>>>>>>>>>>>>>>>>>> Traite l'échantillonage en EEPROM. <<<<<<<<<<<<<<<<<<<<<
      Compteur++;  // Ci-dessous : Valeur 180 secondes pour sauver un échantillon toutes les 3 minutes.
      if (Compteur == 180) {Sauvegarde_un_Echantillon(); Compteur = 0;} // Réarme le compteur pour 3 minutes.
      // >>>>>>>>>>>>>>>>>>>>>>>>>>>> Rafraichir l'écran LCD. <<<<<<<<<<<<<<<<<<<<<<<<<
      if (Mode_affichage_ecran != 4) Creer_les_caracteres_textuels(); // Restituer les caractères spéciaux.
      switch (Mode_affichage_ecran) {
        case 1 : {Affiche_ecran_mesures(); break;} // Affiche les valeurs de U,I et C.
        case 2 : {Affiche_TMP_et_U_Fusible(); break;}
        case 3 : {Affiche_Nombre_Echantillons(); break;}
        case 4 : Affiche_la_rampe_analogique();}
      // >>>>>>>>>>>>>>>>>>>>>>>> Teste pour la fin du processus. <<<<<<<<<<<<<<<<<<<<<
      if (U_Batterie < Ucritique) {
         digitalWrite(Pilotage_RETRO,HIGH); // Allume le rétroéclairage.
         Sauvegarde_le_contexte(); Mode_affichage_ecran = 1; Affiche_ecran_mesures(); Ordre_du_BP = 0; 
         while (Ordre_du_BP == 0) {
           BIP(450); digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
           BIP(300); digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
           Tester_le_BP_A0();} Fin_du_processus(); } }
  // +++++++++++++++++++++ Fin de traiter une fois par seconde. +++++++++++++++++++++++  
  } //======================================= Fin de la boucle de base =====================================

void Creer_les_caracteres_textuels() {
  MonEcran.createChar(1,degre);       // Caractère spécial "°".
  MonEcran.createChar(2,Fleche_Haut); // Flèche vers le haut.
  MonEcran.createChar(3,Jminuscule); // "j" minuscule.
  MonEcran.createChar(4,Gminuscule);  // "g" minuscule.
  MonEcran.createChar(5,Fleche_Bas);  // Flèche vers le bas.  
  MonEcran.createChar(6,Eegu);        // Caractère spécial "é".
  MonEcran.createChar(7,Agrave);      // Caractère spécial "à".
  MonEcran.createChar(8,Pminuscule);}  // "p" minuscule.
  
void  Efface_le_contexte_et_INIT_BAT() {// Si on efface le contexte il faut personnaliser la Batterie.
  Efface_le_contexte();
  Ecrire_ligne_du_haut(); MonEcran.print("Modifier "); Affiche_valeur_capacite_theorique(); MonEcran.print("?");
  Affiche_OUI_NON(); Attendre_un_BP(); if (Ordre_du_BP == 2) Traite_BP_saisie_Capacite();}

void Traite_BP_saisie_Capacite() {
  Ordre_du_BP = 0;
  while (Ordre_du_BP != 5) {
    Ecrire_ligne_du_haut(); Affiche_le_mot_capacite(); MonEcran.print("= "); Affiche_valeur_capacite_theorique();
    Ecrire_ligne_du_bas(); MonEcran.print("SELECT : Sortie.");
    Attendre_un_BP();
    switch (Ordre_du_BP) {// Augmenter ou diminuer de 1 ou 10 emplacements. 
      case 1 : {if (Capacite_theorique < 50) Capacite_theorique++; else BIP(3000); break;}
      case 2 : {if (Capacite_theorique <= 40) Capacite_theorique = Capacite_theorique + 10; else BIP(3000); break;}
      case 3 : {if (Capacite_theorique > 10) Capacite_theorique = Capacite_theorique - 10; else BIP(3000); break;}
      case 4 : if (Capacite_theorique > 1) Capacite_theorique--; else BIP(3000);} } }
  
void Sauvegarde_le_contexte() {
  INDEX = 1023; Ecrire_un_OCTET_en_EEPROM(INDEX, NB_echantillons); // Sauvegarde le nombre d'échantillons effectués.
  INDEX = 1019; Ecrire_un_Float_en_EEPROM(INDEX, Capacite); // Sauvegarde la valeur actuelle de la capacité.
  INDEX = 1018; Ecrire_un_OCTET_en_EEPROM(INDEX, Capacite_theorique);} // Pour le cas ou modifiée par l'utilisateur.
  
void Teste_EEPROM_et_Restitue_le_contexte() {
  INDEX = 1023; NB_echantillons = Lire_un_OCTET_en_EEPROM(INDEX); // Restitue le nombre d'échantillons effectués.
  if (NB_echantillons > 0) Restitue_le_contexte(); else ALERTE_MEMOIRE_VIDE(); }

void Restitue_le_contexte() {
  INDEX = 1023; NB_echantillons = Lire_un_OCTET_en_EEPROM(INDEX); // Restitue le nombre d'échantillons effectués.
  INDEX = 1019; Capacite = Lire_un_Float_en_EEPROM(INDEX); // Restitue la valeur actuelle de la capacité.
  INDEX = 1018; Capacite_theorique = Lire_un_OCTET_en_EEPROM(INDEX); // Restitue pour le cas où modifiée.
  // >>>>>>>>>>>>>>>> Restitue l'heure du dernier échantillon mémorisé <<<<<<<<<<<<
  INDEX = (4 * NB_echantillons) - 4; // Pointe le début du dernier échantillon.
  Heures = Lire_un_OCTET_en_EEPROM(INDEX); Minutes = Lire_un_OCTET_en_EEPROM(INDEX + 1); Secondes = 0;
  INDEX = 4 * NB_echantillons;} // Pointe le premier emplacement libre en EEPROM.

void Efface_le_contexte() {
  INDEX = 1023; Ecrire_un_OCTET_en_EEPROM(INDEX, 0); // "Vide" la mémoire d'échantillons.
  Capacite = 0; NB_echantillons = 0; Compteur = 0; INDEX = 0;} // Replace l'INDEX en début d'EEPROM.

void Sauvegarde_un_Echantillon() { // Laisse INDEX sur le premier octer libre en EEPROM.
  if (NB_echantillons < 251) {
  Ecrire_un_OCTET_en_EEPROM(INDEX, Heures); Ecrire_un_OCTET_en_EEPROM(INDEX, Minutes);
  Ecrire_un_Entier_en_EEPROM(INDEX, CAN_U_Batterie); NB_echantillons++;} }
  
void Affiche_un_espace_sur_USB() {Serial.print(" ");}
void Affiche_trois_espaces_sur_USB() {Serial.print("   ");}
  
void Affiche_en_aveugle_sur_la_ligne_USB() {
  Serial.print("Nombre de mesures = "); Serial.println(NB_echantillons);
  Serial.print("CAPACITEE = "); Serial.print(Capacite,2); Serial.println("Ah");
  Serial.println(); Serial.println("num   H  min  Tension");
  Num_Ech_USB = 1; INDEX = 0; // Pointe le premier emplacement échantillon n°1.
  Compteur_de_ligne = 0;
  while (Num_Ech_USB < (NB_echantillons + 1)) {
        //--------------------------- Affiche une ligne de données. ---------------------------
        if (Num_Ech_USB < 100) Affiche_un_espace_sur_USB();
        if (Num_Ech_USB < 10) Affiche_un_espace_sur_USB(); 
        Serial.print(Num_Ech_USB); Serial.print("  ");
        Heures = Lire_un_OCTET_en_EEPROM(INDEX); INDEX++;
        if (Heures < 10) Affiche_un_espace_sur_USB(); Serial.print(Heures); Affiche_trois_espaces_sur_USB();
        Minutes = Lire_un_OCTET_en_EEPROM(INDEX); INDEX++;
        if (Minutes < 10) Affiche_un_espace_sur_USB(); Serial.print(Minutes); Affiche_trois_espaces_sur_USB();
        CAN_U_Batterie = Lire_un_Entier_en_EEPROM(INDEX); INDEX = INDEX + 2;
        Translate_U_Batterie(); Serial.print(U_Batterie,2); Serial.println();
        Num_Ech_USB++; // Incrémente le n° d'échantillon qui sera affiché.
        //-------------------------- Compte les lignes pour séparer. --------------------------
        Compteur_de_ligne++;
        if (Compteur_de_ligne == 10) {
            Compteur_de_ligne = 0; Serial.println("---------------------");} } }  
  
void Exploite_Enregistrements() {
  INDEX = 1023; NB_echantillons = Lire_un_OCTET_en_EEPROM(INDEX); // Restitue le nombre d'échantillons effectués.
  INDEX = 1019; Capacite = Lire_un_Float_en_EEPROM(INDEX); // Restitue la valeur mémorisée de la capacité. 
  INDEX_MAX = (NB_echantillons - 1) * 4;
  if (NB_echantillons == 0) ALERTE_MEMOIRE_VIDE();
  Affiche_en_aveugle_sur_la_ligne_USB();
  INDEX = 0; // Pointe le premier échantillon.
  Affiche_NB_Echantillons(); Ecrire_ligne_du_bas(); MonEcran.print("Sortie "); MonEcran.write(8);
  MonEcran.print("ar RESET"); Affiche_C_et_Nb = true;
  // >>>>>>>>>>>>>>>>>>>>>>>> Gère le clavier du Shield LCD  <<<<<<<<<<<<<<<<<<<<<<
  Recommence: Affiche_ecran_Memoire(); Attendre_un_BP(); Traite_BP_Exploitation_Memoire(); goto Recommence; }
  
void Affiche_un_espace() { MonEcran.print(" "); }

void Affiche_le_mot_capacite() {
  MonEcran.print("Ca"); MonEcran.write(8); MonEcran.print("acit"); MonEcran.write(6); Affiche_un_espace();}
  
void Affiche_ecran_Memoire() { // INDEX pointe le début d'un échantillon valide en entrée de procédure.
  if (Affiche_C_et_Nb) {
      Affiche_NB_Echantillons(); Ecrire_ligne_du_bas(); Affiche_le_mot_capacite(); MonEcran.print(Capacite,2);}
  else {// Lire des octets en EEPROM ne décale pas le pointeur INDEX.
      Ecrire_ligne_du_haut(); MonEcran.print("  Valeur n"); MonEcran.write(1); Affiche_un_espace();
      MonEcran.print((INDEX / 4) + 1); // Calcule le n° échantillon en fonction de la valeur de INDEX.
      Heures = Lire_un_OCTET_en_EEPROM(INDEX); Minutes = Lire_un_OCTET_en_EEPROM(INDEX + 1);
      CAN_U_Batterie = Lire_un_Entier_en_EEPROM(INDEX + 2); Translate_U_Batterie();
      AFF_H_et_U(); } }
  
void Traite_BP_Exploitation_Memoire() {
  if (Ordre_du_BP == 5) Affiche_C_et_Nb = true; else Affiche_C_et_Nb = false;
  switch (Ordre_du_BP) {// Pointer en avant ou en arrière de 1 ou 10 emplacements. 
      case 1 : {if (INDEX < INDEX_MAX) INDEX = INDEX + 4; else BIP(3000); break;}
      case 2 : {if (INDEX <= (INDEX_MAX - 40)) INDEX = INDEX + 40; else BIP(3000); break;}
      case 3 : {if (INDEX > 39) INDEX = INDEX - 40; else BIP(3000); break;}
      case 4 : if (INDEX > 3) INDEX = INDEX - 4; else BIP(3000); } }

//======================================= Routines pour gérer l'EEPROM ======================================

byte Lire_un_OCTET_en_EEPROM(int ADRESSE) {
  return eeprom_read_byte((unsigned char *) ADRESSE);}

void Ecrire_un_OCTET_en_EEPROM(int ADRESSE, byte OCTET) { // Pointe l'octet libre suivant.
   eeprom_write_byte((unsigned char *) ADRESSE, OCTET); INDEX++;}
   
int Lire_un_Entier_en_EEPROM(int ADRESSE) {
  return eeprom_read_word((unsigned int *) ADRESSE);}
  
void Ecrire_un_Entier_en_EEPROM(int ADRESSE, int MOT16Bits) { // Pointe l'octet libre suivant.
   eeprom_write_word((unsigned int *) ADRESSE, MOT16Bits); INDEX++; INDEX++;}
   
float Lire_un_Float_en_EEPROM(int ADRESSE) {
  return eeprom_read_float((float *) ADRESSE);}
  
void Ecrire_un_Float_en_EEPROM(int ADRESSE, float MOT32Bits) { // Pointe l'octet libre suivant.
   eeprom_write_float((float *) ADRESSE, MOT32Bits); INDEX = INDEX + 4;}

//===========================================================================================================

void Calcule_le_courant_fourni_par_la_batterie() {// de 8610 octets passe à 8678 soit + 68 octets !
  Courant_de_decharge = (0.0071428 * U_Batterie) - 0.0071424; // calcul du courant dans le ventilateur.
  Courant_de_decharge = Courant_de_decharge +((U_Batterie - U_sur_Fusible) / R_Bloc_thermique) ; }
  
void Translate_U_Batterie() {
  U_Batterie = CAN_U_Batterie; // L'entier de numérisation passe dans le réel U_Batterie.
  U_Batterie = (U_Batterie * 20 / 1023) * Correction_U_Batterie;}
  // Pour 5 Vcc sur l'entrée le CNA retourne 1023.
  // Comme U = 4 * E on multiplie par 4 d'où le facteur 20.
      
void Mesurer_le_debit_batterie() {
  CAN_U_Batterie = analogRead(Entree_TENSION); // Uréel = quatre fois la DDP mesurée.
  // Intermédiaire de type int pour sauvegarde sur deux octets en EEPROM.
  Translate_U_Batterie(); // l'entier CAN_U_Batterie transformé en volts dans le réel U_Batterie.
  U_sur_Fusible = analogRead(Entree_Fusible); // Mesuré directement.
  U_sur_Fusible = (U_sur_Fusible * 5 / 1023) * Correction_U_Fusible;}

void Suspendre_le_mesurage() {
  digitalWrite(Pilotage_RETRO,HIGH); // Si mode veille allume le rétroéclairage.
  Ecrire_ligne_du_haut(); MonEcran.print("Fi"); MonEcran.write(4); MonEcran.print("er mesura");
  MonEcran.write(4); MonEcran.print("e ?"); Affiche_OUI_NON(); Attendre_un_BP();
  if (Ordre_du_BP == 2) {Sauvegarde_le_contexte(); Fin_du_processus();} } 

void Affiche_TMP_et_U_Fusible() { Affiche_U_sur_fusible(); Affiche_valeur_temperature();}

void Affiche_ecran_mesures() {
  Ecrire_ligne_du_haut(); MonEcran.print("C=");
  if (Capacite < 10) Affiche_un_zero();
  MonEcran.print(Capacite,2); MonEcran.print("Ah I="); MonEcran.print(Courant_de_decharge,1);
  MonEcran.print("A"); AFF_H_et_U(); } 
  
void AFF_H_et_U() {  
  Ecrire_ligne_du_bas(); if (Heures < 10) Affiche_un_zero();
  if (Heures < 1) Affiche_un_zero(); else MonEcran.print(Heures); MonEcran.print(":");
  if (Minutes < 10) Affiche_un_zero(); if (Minutes < 1) Affiche_un_zero(); else MonEcran.print(Minutes);
  MonEcran.print(":"); if (Secondes < 10) Affiche_un_zero(); if (Secondes < 1) Affiche_un_zero();
  else MonEcran.print(Secondes); MonEcran.print(" U="); MonEcran.print(U_Batterie,1); MonEcran.print("v");}
  
void Affiche_valeur_capacite_theorique() {
  MonEcran.print(Capacite_theorique); MonEcran.print("Ah ");}
  
void Affiche_la_rampe_analogique() {
  //------------------------- Créer la matrice pour le ruban analogique -------------------------
  MonEcran.createChar(1,I); MonEcran.createChar(2,II); MonEcran.createChar(3,III);
  MonEcran.createChar(4,IIII); MonEcran.createChar(5,IIIII);
  //------------------------- Calcule VALEUR à afficher sur le "sablier -------------------------
  VALEUR = Capacite * 96 / Capacite_theorique;
  //--------------------------------- Écrire la ligne du haut -----------------------------------
  Ecrire_ligne_du_haut(); MonEcran.print("<<< 0 "); MonEcran.write(7); Affiche_un_espace();
  Affiche_valeur_capacite_theorique(); if (Capacite_theorique < 10) MonEcran.print(">"); MonEcran.print(">>>");
  //----------------------------------- Tracer le "sablier" -------------------------------------
  Affiche_la_rampe_ANALOGIQUE();}

void Affiche_la_rampe_ANALOGIQUE() {
  byte SAV_VALEUR = VALEUR; // Ici pas besoin d'un float.
  /*================== Afficher les pavés entiers. ======================*/
  VALEUR = (VALEUR / 6) - 1; Ecrire_ligne_du_bas();
  for (byte I = 0 ; I < VALEUR ; I++) MonEcran.write(5);
  /*================== Afficher la fraction de pavé. ====================*/
  VALEUR = SAV_VALEUR % 6;
  switch (byte(VALEUR)) {
    case 1 : {MonEcran.write(1); break;}
    case 2 : {MonEcran.write(2); break;}
    case 3 : {MonEcran.write(3); break;}
    case 4 : {MonEcran.write(4); break;}
    case 5 : {MonEcran.write(5); break;} } }
  
void Affiche_un_zero() {MonEcran.print("0");}

void ALERTE_MEMOIRE_VIDE() {
  Ecrire_ligne_du_haut(); MonEcran.print("> M"); MonEcran.write(6); MonEcran.print("moire vide <");
  Ecrire_ligne_du_bas(); MonEcran.print(".Faire un RESET.");
  BOUCLE_INFINIE();}
    
void BOUCLE_INFINIE() {
  Boucle_infinie: digitalWrite(LED_Verte,!digitalRead(LED_Verte)); // Inverser l'état de la LED verte.
  delay(50); goto Boucle_infinie;}
  
void ALERTE_TEMPERATURE() {
  Ecrire_ligne_du_haut(); MonEcran.print("ALERTE THERMIQUE"); Affiche_valeur_temperature(); ALERTE();}
  
void ALERTE_FUSIBLE() {
  Affiche_U_sur_fusible(); Ecrire_ligne_du_bas(); MonEcran.print("Pas de FUSIBLE !"); ALERTE();}
  
void ALERTE() {
  Sauvegarde_le_contexte(); digitalWrite(Pilotage_RETRO,HIGH); // Si mode veille allume le rétroéclairage.  
  Ordre_du_BP = 0; while (Ordre_du_BP == 0) {BIP(4000); BIP(3000); Tester_le_BP_A0();} Fin_du_processus();}
  
void  Fin_du_processus() {
  Ecrire_ligne_du_haut(); MonEcran.print("Mesures sauv"); MonEcran.write(6); MonEcran.print("es.");
  Ecrire_ligne_du_bas();  MonEcran.print("COUPER BATTERIE.");
  BOUCLE_INFINIE();} // Boucle infinie pour figer l'affichage.
  
void Affiche_U_sur_fusible() {
  Ecrire_ligne_du_haut(); MonEcran.print("Fusible U="); MonEcran.print(U_sur_Fusible,2); MonEcran.print("v");}

void Affiche_valeur_temperature() {
  Ecrire_ligne_du_bas(); MonEcran.print("Tem"); MonEcran.write(8); MonEcran.print(" = ");
  MonEcran.print(Temperature,1); MonEcran.write(1); MonEcran.print("C  ");}

void Affiche_NB_Echantillons() {
  Ecrire_ligne_du_haut(); MonEcran.print("Nb "); MonEcran.write(6); MonEcran.print("chant. = ");
  MonEcran.print(NB_echantillons);}
 
void Affiche_Nombre_Echantillons() {
  Affiche_NB_Echantillons(); Ecrire_ligne_du_bas(); MonEcran.print(" (Maximum 250.)");} 
 
void Affiche_OUI_NON() {
  Ecrire_ligne_du_bas(); MonEcran.print("( ");MonEcran.write(2); MonEcran.print(":OUI  "); MonEcran.write(5);
  MonEcran.print(":NON )");}  

double Conversion_en_degres(int Mesure_CTN) {
  double Tmp_Kelvin;
  Tmp_Kelvin = log(10000.0 * ((1023.0 / Mesure_CTN - 1))); 
  Tmp_Kelvin = 1 / (0.001129148 + (0.000234125 + (0.0000000876741 * Tmp_Kelvin * Tmp_Kelvin ))* Tmp_Kelvin );
  Tmp_Kelvin = Tmp_Kelvin - 273.15; // Conversion des degrés Kelvin en degrés Celcius.
  return Tmp_Kelvin; }

void Attendre_un_BP() { // Attend un clic sur l'un des cinq B.P.
  Ordre_du_BP = 0;
  while (Ordre_du_BP == 0) {Tester_le_BP_A0(); delay(30);
         digitalWrite(LED_Verte,!digitalRead(LED_Verte));} } // Inverser l'état de la LED verte.

void Efface_ligne(byte Ligne) {// Zéro : Haut, 1 : Bas.
  if (Ligne ==0) MonEcran.setCursor(0,0); else MonEcran.setCursor(0,1);
  MonEcran.print("                ");}
  
void Ecrire_ligne_du_haut() {
  Efface_ligne(0); MonEcran.setCursor(0,0);}
  
void Ecrire_ligne_du_bas() {
  Efface_ligne(1); MonEcran.setCursor(0,1);}
  
void BIP(int Frequence) {// 4000 très aigü, 3000 très fort et 500 : Mode clavier.
  tone(BUZZER,Frequence); delay(100); noTone(BUZZER); digitalWrite(BUZZER, LOW);}

void Tester_le_BP_A0() { // La lecture sur A0 donne 0 ou 1023 maximum.
  // >>>>>>>>>>>>> Le B.P. est câblé en "Analogique" <<<<<<<<<<<<<<<<<<
  // Aucun B.P : Temps dans la procédure court et retour = 0,
  // RIGHT = 1, UP = 2, DOWN = 3, LEFT = 4 SELECT = 5.
  Ordre_du_BP = 0; // Aucun BP appuyé.
  unsigned int Moyenne; // Valeur moyenne obtenue par la CAN de A0.
  Moyenne = 1023;
  for (byte I = 0; I < NB_tests_antirebonds; I++)
      {if (analogRead(0) < 830) Moyenne = analogRead(0);}
  //-------- Si appui détecté procéder à la mesure. --------
  if (Moyenne < 830)
     {Moyenne = 0;
      for (byte I = 0; I < NB_tests_antirebonds; I++) Moyenne = Moyenne + analogRead(0);
      //------------- Attendre le relacher du B.P. -------------
      for (byte I = 0; I < NB_tests_antirebonds; I++) {if (analogRead(0) < 830) I = 0;}
      //---------------- traite l'ordre du B.P. ----------------  
      Moyenne = int(Moyenne / NB_tests_antirebonds);
      if (Moyenne < 50) Ordre_du_BP = 1;
      if ((Moyenne > 49) && (Moyenne < 175)) Ordre_du_BP = 2;
      if ((Moyenne > 174) && (Moyenne < 330)) Ordre_du_BP = 3;
      if ((Moyenne > 329) && (Moyenne < 522)) Ordre_du_BP = 4;
      if ((Moyenne > 521) && (Moyenne < 830)) Ordre_du_BP = 5; BIP(500);} }
      
